Unified protocol server lifecycle implementation Unified protocol server implementation for the WebSocket mock server.
Structs
- WsMock
Server - A
MockProtocolServerwrapper around the WebSocket server startup.
Unified protocol server lifecycle implementation Unified protocol server implementation for the WebSocket mock server.
MockProtocolServer wrapper around the WebSocket server startup.